==> movies_lib-0.1.0.tar.gz: movies_lib-0.1.0/README.md <==
# Библиотека для работы с фильмами и рейтингами
##### Описание основных классов и их возможностей
1. Класс Rating. Отвечает за рейтинг, принимает обязательные значения: имя того кто оценил и оценка.
* Имеет метод edit_rating принимающий имя и оценку для установки.
2. Класс Movie. Описывает сущность фильма, принимает обязательный параметр название и не обязательный список объектов класса Rating.
* метод full_movie_info показывает полную информацию о фильме
* метод get_avg возвращает средний рейтинг фильма 
* метод rate_movie принимает имя и оценку и пытается установить эту оценку фильму. Выкидывает ошибку ValueError если введено не число для оценки.
* Также реализован метод str для вывода названия и оценки фильма(краткая информация). Соответственно достаточно просто через print выводить объект класса Movie.
3. Класс MovieList. Описывает список фильмов. Имеет необязательный параметр - список объектов класса Movie.
* метод add_movie принимает объект класса Movie и добавляет в список
* метод delete_movie принимает объект класса Movie и удаляет из списка
* метод get_movie принимает название фильма и возращает либо объект Movie либо None если ничего не найдено
* метод print_movies выводит отсортированный по названиям список фильмов
4. Класс Tools. Класс в основном нужный для записи-чтения из файла
* метод write_file принимает объект класса MovieList и путь до файла куда нужно записать фильмы с рейтингами в формате json.
* метод read_from_file принимает путь до файла с которого нужно считать фильмы с рейтингами в формате json.
* метод get_input принимающий текст который далее выводится в инпуте, возвращает то что введет пользователь
* метод get_menu выводит меню для программы

==> movies_lib-0.1.2.tar.gz: movies_lib-0.1.2/README.md <==
# Библиотека для работы с фильмами и рейтингами
##### Описание основных классов и их возможностей
1. Класс Rating. Отвечает за рейтинг, принимает обязательные значения: имя того кто оценил и оценка.
* Имеет метод edit_rating принимающий имя и оценку для установки.
2. Класс Movie. Описывает сущность фильма, принимает обязательный параметр название и не обязательный список объектов класса Rating.
* метод full_movie_info показывает полную информацию о фильме
* метод get_avg возвращает средний рейтинг фильма 
* метод rate_movie принимает имя и оценку и пытается установить эту оценку фильму через метод edit_rating класса Rating. Выкидывает ошибку ValueError если введено не число для оценки и выводит текстовые сообщения если введена неверная оценка. Возможные варианты (0-10).
* Также реализован метод str для вывода названия и оценки фильма(краткая информация). Соответственно достаточно просто через print выводить объект класса Movie.
3. Класс MovieList. Описывает список фильмов. Имеет необязательный параметр - список объектов класса Movie.
* метод add_movie принимает объект класса Movie и добавляет в список
* метод delete_movie принимает объект класса Movie и удаляет из списка
* метод get_movie принимает название фильма и возращает либо объект Movie либо None если ничего не найдено
* метод print_movies выводит отсортированный по названиям список фильмов
4. Класс Tools. Класс в основном нужный для записи-чтения из файла
* метод write_file принимает объект класса MovieList и путь до файла куда нужно записать фильмы с рейтингами в формате json.
* метод read_from_file принимает путь до файла с которого нужно считать фильмы с рейтингами в формате json.
* метод get_input принимающий текст который далее выводится в инпуте, возвращает то что введет пользователь
* метод get_menu выводит меню для программы
